==> pcp-gui_1.4.5.tar.gz: pcp-gui-1.4.5/src/chart/main.h <==
/*
 * Copyright (c) 2006, Ken McDonell.  All Rights Reserved.
 * Copyright (c) 2007, Aconex.  All Rights Reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 */
#ifndef MAIN_H
#define MAIN_H

#include <stdio.h>
#include <pcp/pmapi.h>
#include <pcp/impl.h>

#include "tab.h"
#include "console.h"
#include "colorscheme.h"
#include "timecontrol.h"
#include "fileiconprovider.h"
#include "pmchart.h"
#include "version.h"

typedef struct {
	// Sampling
	double chartDelta;
	bool chartDeltaModified;
	double loggerDelta;
	bool loggerDeltaModified;
	int sampleHistory;
	bool sampleHistoryModified;
	int visibleHistory;
	bool visibleHistoryModified;

	// Default Colors
	QColor chartBackground;
	QString chartBackgroundName;
	bool chartBackgroundModified;
	QColor chartHighlight;
	QString chartHighlightName;
	bool chartHighlightModified;
	// Color Schemes
	ColorScheme defaultScheme;
	bool defaultSchemeModified;
	QList<ColorScheme> colorSchemes;
	bool colorSchemesModified;

	// Toolbar
	int initialToolbar;
	bool initialToolbarModified;
	int nativeToolbar;
	bool nativeToolbarModified;
	int toolbarLocation;
	int toolbarLocationModified;
	QStringList toolbarActions;
	bool toolbarActionsModified;
} Settings;

extern Settings globalSettings;
extern void readSettings();
extern void writeSettings();
extern QColor nextColor(QString, int *);

extern int Cflag;
extern int Lflag;
extern int Wflag;
extern char *outfile;
extern char *outgeometry;
extern QFont *globalFont;

extern GroupControl *activeGroup;
extern GroupControl *liveGroup;
extern GroupControl *archiveGroup;

class PmChart;
extern PmChart *pmchart;

class TimeControl;
extern TimeControl *pmtime;

extern double tosec(struct timeval);
extern double torange(struct timeval, int);
extern void fromsec(double, struct timeval *);
extern char *timeString(double);
extern char *timeHiResString(double);
extern void nomem(void);

#endif	// MAIN_H

==> pcp-gui_1.5.11.tar.gz: pcp-gui-1.5.11/src/chart/main.h <==
/*
 * Copyright (c) 2006, Ken McDonell.  All Rights Reserved.
 * Copyright (c) 2007, Aconex.  All Rights Reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 */
#ifndef MAIN_H
#define MAIN_H

#include <stdio.h>
#include <pcp/pmapi.h>
#include <pcp/impl.h>

#include "tab.h"
#include "console.h"
#include "colorscheme.h"
#include "timecontrol.h"
#include "fileiconprovider.h"
#include "pmchart.h"
#include "version.h"

typedef struct {
	// Sampling
	double chartDelta;
	bool chartDeltaModified;
	double loggerDelta;
	bool loggerDeltaModified;
	int sampleHistory;
	bool sampleHistoryModified;
	int visibleHistory;
	bool visibleHistoryModified;

	// Default Colors
	QColor chartBackground;
	QString chartBackgroundName;
	bool chartBackgroundModified;
	QColor chartHighlight;
	QString chartHighlightName;
	bool chartHighlightModified;
	// Color Schemes
	ColorScheme defaultScheme;
	bool defaultSchemeModified;
	QList<ColorScheme> colorSchemes;
	bool colorSchemesModified;

	// Toolbar
	int initialToolbar;
	bool initialToolbarModified;
	int nativeToolbar;
	bool nativeToolbarModified;
	int toolbarLocation;
	int toolbarLocationModified;
	QStringList toolbarActions;
	bool toolbarActionsModified;
} Settings;

extern Settings globalSettings;
extern void readSettings();
extern void writeSettings();
extern QColor nextColor(QString, int *);

extern int Cflag;
extern int Lflag;
extern int Wflag;
extern char *outfile;
extern char *outgeometry;
extern QFont *globalFont;

extern GroupControl *activeGroup;
extern GroupControl *liveGroup;
extern GroupControl *archiveGroup;

class PmChart;
extern PmChart *pmchart;

class TimeControl;
extern TimeControl *pmtime;

extern double tosec(struct timeval);
extern double torange(struct timeval, int);
extern void fromsec(double, struct timeval *);
extern char *timeString(double);
extern char *timeHiResString(double);
extern void nomem(void);

/*
 * number of Y pixels to move the time axis up when exporting to
 * an image or printing
 */
#define TIMEAXISFUDGE 0

#endif	// MAIN_H
